.. _profiles-page:

************************************************
Config files for the different nextflow profiles
************************************************

Are detailed here the different config files that are automatically generated by the install process.

cluster
=======

The ``cluster.config`` contains the information to submit the jobs on a computing cluster.

.. literalinclude:: ../data/conf/cluster.config

conda
=====

Are listed in the ``conda.config`` file only the tools available in conda.

.. literalinclude:: ../data/conf/conda.config

docker
======

All the tools are listed in the ``docker.config`` file.

.. literalinclude:: ../data/conf/docker.config

multiconda
==========

Are listed in the ``multiconda.config`` file only the tools available in conda.

.. literalinclude:: ../data/conf/multiconda.config

multipath
=========

All the tools but ``onlyLinux`` are listed in the ``multipath.config`` file.

.. literalinclude:: ../data/conf/multipath.config

path
====

All the tools but ``onlyLinux`` are listed in the ``path.config`` file.

.. literalinclude:: ../data/conf/path.config

podman
======

All the tools are listed in the ``podman.config`` file.

.. literalinclude:: ../data/conf/podman.config

singularity
===========

All the tools are listed in the ``singularity.config`` file.

.. literalinclude:: ../data/conf/singularity.config

